;
; $Id: cvt_key_tbl.kt,v 1.2 1991/11/25 02:51:58 proj Exp $
;
; key code conversion table for KTERM
;----------------------------------
; ↓、次候補
kcud1	\x92
; ←
kcub1	\x91
; →
kcuf1	\x90
; ↑、前候補
kcuu1	\x93
;
; ひらがな/カタカナ
kf1	\x81
kf25	\x81
; 全角/半角
kf2	\x82
kf26	\x82
; ローマ字
kf3	\x83
kf27	\x83
;
; 辞書操作
kf4	\x84
; ローマ字かな 数字全角
kf5	\x85
; 罫線 細い
kf6	\x86
; 罫線 太い
kf7	\x87
; 未使用 予約 勝手に使うな
kf8	\x88
kf9	\x89
kf10	\x8A
;
; 消去
kf11	\x8B
; 呼出し
kf12	\x8C
; 文節縮め
kf13	\x8D 
; 文節伸ばし
kf14	\x94
;
; 変換
kf15	\x9E
; 確定
kf16	\x9F
;
; 登録
kf17	\x95
; 辞書操作
kf18	\x96
; 区点
kf19	\x97
; ＪＩＳ
kf20	\x98
;
; 行頭
kf21	\x9A
; 消去、逆変換
kf22	\x99
; 行末
kf23	\x9B
; 全候補、解除
kf24	\x9C
